<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da_DK">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../ui/about.ui" line="6"/>
        <source>About Wally</source>
        <translation>Om Wally</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="65"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 desktop wallpaper changer&lt;br /&gt;Author: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;I&apos;d like to thank Vincent Willem van Gogh for the logo :)&lt;br /&gt;&lt;br /&gt;Web site: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;You can contact me at &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 Baggrundsbillede skift &lt;br /&gt;Forfatter: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;Jeg vil gerne takke Vincent Willem van Gogh for logoet :)&lt;br /&gt;&lt;br /&gt;Web adresse: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;Du kan kontakte mig på &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="94"/>
        <source>Details &gt;&gt;</source>
        <translation>Detailer &gt;&gt;</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="104"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="152"/>
        <source>Extension</source>
        <translation>Udvidelse</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="157"/>
        <source>Description</source>
        <translation>Forklaring</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="165"/>
        <source>Supported image formats:</source>
        <translation>Understøttede billed formater:</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="172"/>
        <source>Additional info:</source>
        <translation>Yderligere information:</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="244"/>
        <source>Language</source>
        <translation>Sprog</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="249"/>
        <source>Translator</source>
        <translation>Oversætter</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="257"/>
        <source>Translations:</source>
        <translation>Oversættelser:</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="47"/>
        <source>Compiled with:</source>
        <translation>Kompileret med:</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="49"/>
        <source>EXIF library:</source>
        <translation>EXIF bibliotek:</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="52"/>
        <source>present</source>
        <translation>fundet</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="54"/>
        <source>not present</source>
        <translation>ikke fundet</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="58"/>
        <source>English</source>
        <translation>Engelsk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="60"/>
        <source>Italian</source>
        <translation>Italiensk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="62"/>
        <source>Russian</source>
        <translation>Russisk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="64"/>
        <source>Spanish</source>
        <translation>Spansk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="66"/>
        <source>Portuguese (Brazil)</source>
        <translation>Portugisisk (Braziliansk)</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="68"/>
        <source>German</source>
        <translation>Tysk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="70"/>
        <source>French</source>
        <translation>Fransk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="72"/>
        <source>Czech</source>
        <translation>Tjekkisk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="74"/>
        <source>Chinese</source>
        <translation>Kinesisk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="76"/>
        <source>Polish</source>
        <translation>Polsk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="78"/>
        <source>Catalan</source>
        <translation>Katalansk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="80"/>
        <source>Greek</source>
        <translation>Græsk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="82"/>
        <source>Korean</source>
        <translation>Koreansk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="84"/>
        <source>Hungarian</source>
        <translation>Ungarsk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="86"/>
        <source>Danish</source>
        <translation>Dansk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="88"/>
        <source>Swedish</source>
        <translation>Svensk</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="90"/>
        <source>Turkish</source>
        <translation>Tyrkisk</translation>
    </message>
</context>
<context>
    <name>Bing::DialogWidget</name>
    <message>
        <location filename="../../src/bing.cpp" line="304"/>
        <source>All of these words</source>
        <translation>Alle disse ord</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="305"/>
        <source>Any of these words</source>
        <translation>Et af disse ord</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="308"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="314"/>
        <source>Strict</source>
        <translation>Hård</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="315"/>
        <source>Moderate</source>
        <translation>Moderat</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="316"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="319"/>
        <source>Adult filter:</source>
        <translation>Voksenfilter:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="342"/>
        <source>Bing item</source>
        <translation>Bing post</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="343"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ufiltreret indhold kan vise upassende eller direkte pornografiske billeder</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="354"/>
        <source>Edit Bing item</source>
        <translation>Rediger Bing post</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="361"/>
        <source>Add Bing item</source>
        <translation>Tilføj Bing post</translation>
    </message>
</context>
<context>
    <name>Bing::Item</name>
    <message>
        <location filename="../../src/bing.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Mærke:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="58"/>
        <source>and</source>
        <translation>og</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="58"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="59"/>
        <source>Adult filter:</source>
        <translation>Voksenfilter:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="64"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="68"/>
        <source>Moderate</source>
        <translation>Moderat</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="73"/>
        <source>Strict</source>
        <translation>Hård</translation>
    </message>
</context>
<context>
    <name>Buzznet::DialogWidget</name>
    <message>
        <location filename="../../src/buzznet.cpp" line="225"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/buzznet.cpp" line="248"/>
        <source>Edit Buzznet item</source>
        <translation>Rediger Buzzet post</translation>
    </message>
    <message>
        <location filename="../../src/buzznet.cpp" line="253"/>
        <source>Add Buzznet item</source>
        <translation>Tilføj Buzzet post</translation>
    </message>
</context>
<context>
    <name>Buzznet::Item</name>
    <message>
        <location filename="../../src/buzznet.cpp" line="42"/>
        <source>Tag:</source>
        <translation>Mærke:</translation>
    </message>
</context>
<context>
    <name>DeviantArt::DialogWidget</name>
    <message>
        <location filename="../../src/deviantart.cpp" line="247"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="252"/>
        <source>Strict</source>
        <translation>Hård</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="253"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="256"/>
        <source>Adult filter:</source>
        <translation>Voksenfilter:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="277"/>
        <source>deviantART item</source>
        <translation>deviantART post</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="278"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ufiltreret indhold kan vise upassende eller direkte pornografiske billeder</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="289"/>
        <source>Edit deviantART item</source>
        <translation>Rediger deviantART post</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="295"/>
        <source>Add deviantART item</source>
        <translation>Tilføj deviantART post</translation>
    </message>
</context>
<context>
    <name>DeviantArt::Item</name>
    <message>
        <location filename="../../src/deviantart.cpp" line="43"/>
        <source>Tag:</source>
        <translation>Mærke:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="44"/>
        <source>Adult filter:</source>
        <translation>Voksenfilter:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="49"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="54"/>
        <source>Strict</source>
        <translation>Hård</translation>
    </message>
</context>
<context>
    <name>Exif::InfoDialog</name>
    <message>
        <location filename="../../src/exif.cpp" line="260"/>
        <source>EXIF information</source>
        <translation>EXIF information</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="274"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="275"/>
        <source>Value</source>
        <translation>Værdi</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="298"/>
        <source>No EXIF information available</source>
        <translation>Ingen EXIF information tilgængelig</translation>
    </message>
</context>
<context>
    <name>Files::Core</name>
    <message>
        <location filename="../../src/files.cpp" line="145"/>
        <source>Loading folder...</source>
        <translation>Læser mappe...</translation>
    </message>
</context>
<context>
    <name>Files::LabelPreview</name>
    <message>
        <location filename="../../src/files.cpp" line="261"/>
        <source>No preview available</source>
        <translation>Ingen visning tilgængelig</translation>
    </message>
</context>
<context>
    <name>Files::SettingsWidget</name>
    <message>
        <location filename="../../include/files.h" line="79"/>
        <source>Files</source>
        <translation>Filer</translation>
    </message>
    <message>
        <location filename="../../src/files.cpp" line="281"/>
        <location filename="../../src/files.cpp" line="334"/>
        <source>Select a photo</source>
        <translation>Vælg et foto</translation>
    </message>
    <message>
        <location filename="../../src/files.cpp" line="297"/>
        <location filename="../../src/files.cpp" line="302"/>
        <source>Select a folder</source>
        <translation>Vælg en mappe</translation>
    </message>
</context>
<context>
    <name>FilesSettingsWidget</name>
    <message>
        <location filename="../../ui/files.ui" line="15"/>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="39"/>
        <source>Add a photo</source>
        <translation>Tilføj et foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="59"/>
        <source>Add photos in folder</source>
        <translation>Tilføj fotos til en mappe</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="82"/>
        <source>Delete photo</source>
        <translation>Slet foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="118"/>
        <source>Move photo up</source>
        <translation>Flyt foto op</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="141"/>
        <source>Move photo down</source>
        <translation>Flyt foto ned</translation>
    </message>
</context>
<context>
    <name>Flickr::DialogWidget</name>
    <message>
        <location filename="../../src/flickr.cpp" line="395"/>
        <source>All of these words</source>
        <translation>Alle disse ord</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="396"/>
        <source>Any of these words</source>
        <translation>Et af disse ord</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="400"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="404"/>
        <source>Full text</source>
        <translation>Fuld tekst</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="405"/>
        <source>Tags only</source>
        <translation>Kun tags</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="413"/>
        <source>Largest</source>
        <translation>Største</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="414"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="415"/>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="416"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="417"/>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="418"/>
        <source>Thumbnail</source>
        <translation>Negl</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="419"/>
        <source>Square</source>
        <translation>Firkant</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="420"/>
        <source>Smallest</source>
        <translation>Mindste</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="425"/>
        <source>Interestingness desc</source>
        <translation>Intresante faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="426"/>
        <source>Relevance</source>
        <translation>Relevans</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="427"/>
        <source>Date posted desc</source>
        <translation>Dato indlagt faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="428"/>
        <source>Date taken desc</source>
        <translation>Dato tager faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="429"/>
        <source>Interestingness asc</source>
        <translation>Intresante faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="430"/>
        <source>Date posted asc</source>
        <translation>Dato indlagt faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="431"/>
        <source>Date taken asc</source>
        <translation>Dato tager faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="434"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="436"/>
        <source>Order:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="478"/>
        <source>Edit Flickr item</source>
        <translation>Rediger Flickr post</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="496"/>
        <source>Add Flickr item</source>
        <translation>Tilføj  Flickr post</translation>
    </message>
</context>
<context>
    <name>Flickr::Item</name>
    <message>
        <location filename="../../src/flickr.cpp" line="58"/>
        <source>Text:</source>
        <translation>Tekst:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="60"/>
        <source>Tags:</source>
        <translation>Mærker:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="61"/>
        <source>and</source>
        <translation>og</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="62"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="66"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="69"/>
        <source>Largest</source>
        <translation>Største</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="70"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="71"/>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="72"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="73"/>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="74"/>
        <source>Thumbnail</source>
        <translation>Negl</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="75"/>
        <source>Square</source>
        <translation>Firkant</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="76"/>
        <source>Smallest</source>
        <translation>Mindste</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="79"/>
        <source>Order:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="82"/>
        <source>Interestingness desc</source>
        <translation>Intresante faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="83"/>
        <source>Relevance</source>
        <translation>Relevans</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="84"/>
        <source>Date posted desc</source>
        <translation>Dato indlagt faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="85"/>
        <source>Date taken desc</source>
        <translation>Dato taget faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="86"/>
        <source>Interestingness asc</source>
        <translation>Intresante faldende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="87"/>
        <source>Date posted asc</source>
        <translation>Dato indlagt stigende</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="88"/>
        <source>Date taken asc</source>
        <translation>Dato taget stigende</translation>
    </message>
</context>
<context>
    <name>Folders::DialogWidget</name>
    <message>
        <location filename="../../src/folders.cpp" line="447"/>
        <location filename="../../src/folders.cpp" line="456"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="448"/>
        <location filename="../../src/folders.cpp" line="479"/>
        <source>Remote</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="463"/>
        <source>Include subfolders</source>
        <translation>Inkluder undermapper</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="469"/>
        <source>Folder:</source>
        <translation>Mappe:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="488"/>
        <source>Passive</source>
        <translation>Passiv</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="489"/>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="501"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="503"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="505"/>
        <source>Transfer mode:</source>
        <translation>Overførselstype:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="507"/>
        <source>Username:</source>
        <translation>Brugernavn:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="509"/>
        <source>Password:</source>
        <translation>Posord:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="511"/>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="534"/>
        <location filename="../../src/folders.cpp" line="539"/>
        <source>Select a folder</source>
        <translation>Vælg en mappe</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="588"/>
        <source>Edit folder</source>
        <translation>Rediger mappe</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="614"/>
        <source>Add folder</source>
        <translation>Tilføj mappe</translation>
    </message>
</context>
<context>
    <name>Folders::LocalItem</name>
    <message>
        <location filename="../../src/folders.cpp" line="149"/>
        <source>(with subfolders)</source>
        <translation>(med undermapper)</translation>
    </message>
</context>
<context>
    <name>Folders::RemoteItem</name>
    <message>
        <location filename="../../src/folders.cpp" line="253"/>
        <source>Transfer mode:</source>
        <translation>Overførselstype:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="254"/>
        <source>passive</source>
        <translation>passiv</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="254"/>
        <source>active</source>
        <translation>aktiv</translation>
    </message>
</context>
<context>
    <name>Folders::SettingsWidget</name>
    <message>
        <location filename="../../include/folders.h" line="201"/>
        <source>Folders</source>
        <translation>Mapper</translation>
    </message>
</context>
<context>
    <name>FoldersSettingsWidget</name>
    <message>
        <location filename="../../ui/folders.ui" line="15"/>
        <source>Folders</source>
        <translatorcomment>Mappe</translatorcomment>
        <translation>Mapper</translation>
    </message>
    <message>
        <location filename="../../ui/folders.ui" line="26"/>
        <source>Add a folder</source>
        <translation>Tilføj en mappe</translation>
    </message>
    <message>
        <location filename="../../ui/folders.ui" line="49"/>
        <source>Delete folder</source>
        <translation>Slet mappe</translation>
    </message>
</context>
<context>
    <name>Google::DialogWidget</name>
    <message>
        <location filename="../../src/google.cpp" line="347"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="352"/>
        <source>Strict</source>
        <translation>Hård</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="353"/>
        <source>Moderate</source>
        <translation>Moderat</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="354"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="357"/>
        <source>Adult filter:</source>
        <translation>Voksenfilter:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="378"/>
        <source>Google item</source>
        <translation>Google post</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="379"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ufiltreret indhold kan vise upassende eller direkte pornografiske billeder</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="390"/>
        <source>Edit Google item</source>
        <translation>Rediger Google post</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="396"/>
        <source>Add Google item</source>
        <translation>Tilføj Google post</translation>
    </message>
</context>
<context>
    <name>Google::Item</name>
    <message>
        <location filename="../../src/google.cpp" line="55"/>
        <source>Text:</source>
        <translation>Tekst:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="56"/>
        <source>Adult filter:</source>
        <translation>Voksenfilter:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="61"/>
        <source>Off</source>
        <translation>Fra</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="65"/>
        <source>Moderate</source>
        <translation>Moderat</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="70"/>
        <source>Strict</source>
        <translation>Hård</translation>
    </message>
</context>
<context>
    <name>Gui::ColorButton</name>
    <message>
        <location filename="../../src/gui.cpp" line="132"/>
        <location filename="../../src/gui.cpp" line="140"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
</context>
<context>
    <name>History::Dialog</name>
    <message>
        <location filename="../../src/history.cpp" line="364"/>
        <source>Right-click on items to show options</source>
        <translation>Højreklik på poster for at vise indstillinger</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="395"/>
        <location filename="../../src/history.cpp" line="596"/>
        <location filename="../../src/history.cpp" line="613"/>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="440"/>
        <source>Please wait...</source>
        <translation>Vent venligst...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="441"/>
        <source>Downloading photo...</source>
        <translation>Henter foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="442"/>
        <source>Abort</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="454"/>
        <location filename="../../src/history.cpp" line="458"/>
        <source>Save photo</source>
        <translation>Gem foto</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="456"/>
        <location filename="../../src/history.cpp" line="461"/>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Billedtyper  (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="596"/>
        <source>Photo has been saved</source>
        <translation>Foto gemt</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="613"/>
        <source>There was an error during download</source>
        <translation>Der opstod en fejl ved hentning</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="663"/>
        <source>View photo...</source>
        <translation>Se foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="667"/>
        <source>Get EXIF info...</source>
        <translation>Vis EXIF info...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="671"/>
        <source>Save photo...</source>
        <translation>Gem foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="675"/>
        <source>Set as background</source>
        <translation>Vælg som baggrund</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="679"/>
        <source>Explore image source</source>
        <translation>Undersøg billed kilde</translation>
    </message>
</context>
<context>
    <name>History::EngineQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="70"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
</context>
<context>
    <name>History::PhotosQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="238"/>
        <source>(no title)</source>
        <translation>(ingen titel)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="240"/>
        <source>by:</source>
        <translation>af:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="241"/>
        <source>(no author)</source>
        <translation>(ingen forfatter)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="243"/>
        <source>Date:</source>
        <translation>Dato:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="245"/>
        <source>Location:</source>
        <translation>Lokation:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="246"/>
        <source>unknown</source>
        <translation>ukendt</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="248"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="250"/>
        <source>Image size:</source>
        <translation>Billed størrelse:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="252"/>
        <source>Engine:</source>
        <translation>Motor:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>EXIF:</source>
        <translation>EXIF:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
</context>
<context>
    <name>History::TagsQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="99"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
</context>
<context>
    <name>HttpEngine::SettingsWidget</name>
    <message>
        <location filename="../../src/httpengine.cpp" line="656"/>
        <location filename="../../src/httpengine.cpp" line="661"/>
        <source>Select a folder</source>
        <translation>Vælg en mappe</translation>
    </message>
</context>
<context>
    <name>HttpSettingsWidget</name>
    <message>
        <location filename="../../ui/http.ui" line="12"/>
        <source>Photo sets</source>
        <translation>Foto sæt</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="20"/>
        <source>Add a photo set</source>
        <translation>Tilføj et foto sæt</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="43"/>
        <source>Delete photo set</source>
        <translation>Slet et foto sæt</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="97"/>
        <source>Options</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="103"/>
        <source>Save photos</source>
        <translation>Gem fotos</translation>
    </message>
</context>
<context>
    <name>Ipernity::DialogWidget</name>
    <message>
        <location filename="../../src/ipernity.cpp" line="284"/>
        <source>All of these words</source>
        <translation>Alle disse ord</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="285"/>
        <source>Any of these words</source>
        <translation>Et af disse ord</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="288"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="292"/>
        <source>Full text</source>
        <translation>Fuld tekst</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="293"/>
        <source>Tags only</source>
        <translation>Kun tags</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="309"/>
        <source>Ipernity item</source>
        <translation>Ipernity post</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="310"/>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Kan vise upassende eller direkte pornografiske billeder</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="331"/>
        <source>Edit Ipernity item</source>
        <translation>Rediger Ipernity post</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="347"/>
        <source>Add Ipernity item</source>
        <translation>Tilføj Ipernity post</translation>
    </message>
</context>
<context>
    <name>Ipernity::Item</name>
    <message>
        <location filename="../../src/ipernity.cpp" line="57"/>
        <source>Text:</source>
        <translation>Tekst:</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="58"/>
        <location filename="../../src/ipernity.cpp" line="63"/>
        <source>and</source>
        <translation>og</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="59"/>
        <location filename="../../src/ipernity.cpp" line="64"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="66"/>
        <source>Tags:</source>
        <translation>Mærker:</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../src/main.cpp" line="65"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="66"/>
        <source>Another instance of</source>
        <translation>Endnu et eksempel på</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="68"/>
        <source>is already running</source>
        <translation>Kører allerede</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="77"/>
        <source>Disclaimer</source>
        <translation>Ansvarsfraskrivelse</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="78"/>
        <source>&lt;b&gt;The Author takes no responsibility over the content that Wally downloads from photo sharing web sites.&lt;br&gt;The Author is in no way responsible for any such content.&lt;/b&gt;&lt;br&gt;&lt;br&gt;If this is a problem for you, please use only local engines like &quot;Files&quot; or local &quot;Folders&quot;.&lt;br&gt;Otherwise, please select &lt;b&gt;&quot;No&quot;&lt;/b&gt; to exit Wally, or use it &lt;b&gt;at your own risk.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(If you proceed, this message will appear only once)&lt;br&gt;&lt;br&gt;Do you accept the above condition?</source>
        <translation>&lt;b&gt;Forfatteren har intet ansvar for indholdet som Wally henter (downloader) fra fotodeling web sites.&lt;br&gt;Forfatteren er under ingen omstændigheder ansvarlig for dette indhold.&lt;/b&gt;&lt;br&gt;&lt;br&gt;Hvis dette er et problem for dig, brug da venligst kun egne som &quot;Filer&quot; eller egne &quot;Mapper&quot;.&lt;br&gt;I modsat fald, vælg venligst &lt;b&gt;&quot;Nej&quot;&lt;/b&gt; for at forlade Wally, eller brug det &lt;b&gt;på eget ansvar.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(Hvis du fortsætter, vil denne meddelse kun blive vist denne ene gang)&lt;br&gt;&lt;br&gt;Accepterer du ovennævnte?</translation>
    </message>
</context>
<context>
    <name>Map::View</name>
    <message>
        <location filename="../../src/mapviewer.cpp" line="387"/>
        <source>Drag to select. Right-click to zoom</source>
        <translation>Træk for at vælge. Højreklik for zoom</translation>
    </message>
    <message>
        <location filename="../../src/mapviewer.cpp" line="395"/>
        <source>Zoom %1x</source>
        <translation>Zoom %1x</translation>
    </message>
</context>
<context>
    <name>Map::Viewer</name>
    <message>
        <location filename="../../src/mapviewer.cpp" line="434"/>
        <source>Map viewer</source>
        <translation>Kort visning</translation>
    </message>
</context>
<context>
    <name>Panoramio::DialogWidget</name>
    <message>
        <location filename="../../src/panoramio.cpp" line="322"/>
        <source>Select on map</source>
        <translation>Vælg op kort</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="328"/>
        <source>Longitude (min):</source>
        <translation>Længdegrad (min):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="330"/>
        <source>Longitude (max):</source>
        <translation>Længdegrad (max):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="332"/>
        <source>Latitude (min):</source>
        <translation>Breddegrad (min):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="334"/>
        <source>Latitude (max):</source>
        <translation>Breddegrad (max):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="352"/>
        <source>Popularity</source>
        <translation>Popularitet</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="353"/>
        <source>Upload date</source>
        <translation>Overført dato</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="358"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="359"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="360"/>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="361"/>
        <source>Thumbnail</source>
        <translation>Negl</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="362"/>
        <source>Square</source>
        <translation>Firkant</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="363"/>
        <source>Mini square</source>
        <translation>Mini firmant</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="366"/>
        <source>Order:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="367"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="414"/>
        <source>Edit Panoramio item</source>
        <translation>Rediger Panoramio post</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="427"/>
        <source>Add Panoramio item</source>
        <translation>Tilføj Panoramio post</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="435"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="435"/>
        <source>Coordinates must be different</source>
        <translation>Koordinater skal være forskellige</translation>
    </message>
</context>
<context>
    <name>Panoramio::Item</name>
    <message>
        <location filename="../../src/panoramio.cpp" line="185"/>
        <source>lat:</source>
        <translation>læn:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="186"/>
        <source>lon:</source>
        <translation>brd:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="284"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="285"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="286"/>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="287"/>
        <source>Thumbnail</source>
        <translation>Negl</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="288"/>
        <source>Square</source>
        <translation>Firkant</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="289"/>
        <source>Mini square</source>
        <translation>Mini firkant</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="294"/>
        <source>Popularity</source>
        <translation>Popularitet</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="295"/>
        <source>Upload date</source>
        <translation>Overført dato</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="298"/>
        <source>Longitude:</source>
        <translation>Længdegrad:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="301"/>
        <source>Latitude:</source>
        <translation>Breddegrad:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="304"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="305"/>
        <source>Order:</source>
        <translation>Orden:</translation>
    </message>
</context>
<context>
    <name>Photobucket::DialogWidget</name>
    <message>
        <location filename="../../src/photobucket.cpp" line="275"/>
        <source>All of these words</source>
        <translation>Alle disse ord</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="276"/>
        <source>Any of these words</source>
        <translation>Et af disse ord</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="279"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="293"/>
        <source>Photobucket item</source>
        <translation>Photobucket post</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="294"/>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Kan vise upassende eller direkte pornografiske billeder</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="311"/>
        <source>Edit Photobucket item</source>
        <translation>Rediger Photobucket post</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="317"/>
        <source>Add Photobucket item</source>
        <translation>Tilføj Photobucket post</translation>
    </message>
</context>
<context>
    <name>Photobucket::Item</name>
    <message>
        <location filename="../../src/photobucket.cpp" line="81"/>
        <source>Text:</source>
        <translation>Tekst:</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="82"/>
        <source>and</source>
        <translation>og</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="83"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
</context>
<context>
    <name>Picasa::DialogWidget</name>
    <message>
        <location filename="../../src/picasa.cpp" line="255"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/picasa.cpp" line="278"/>
        <source>Edit Picasa item</source>
        <translation>Rediger Picasa post</translation>
    </message>
    <message>
        <location filename="../../src/picasa.cpp" line="283"/>
        <source>Add Picasa item</source>
        <translation>Tilføj  Picasa post</translation>
    </message>
</context>
<context>
    <name>Picasa::Item</name>
    <message>
        <location filename="../../src/picasa.cpp" line="47"/>
        <source>Text:</source>
        <translation>Tekst:</translation>
    </message>
</context>
<context>
    <name>Pikeo::DialogWidget</name>
    <message>
        <location filename="../../src/pikeo.cpp" line="268"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="273"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="274"/>
        <source>Most viewed</source>
        <translation>Mest sete</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="275"/>
        <source>Upload date</source>
        <translation>Overført dato</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="276"/>
        <source>Date taken</source>
        <translation>Dato taget</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="277"/>
        <source>Group add date</source>
        <translation>Gruppe tilføj dato</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="278"/>
        <source>Comment date</source>
        <translation>Kommantar dato</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="282"/>
        <source>Ascending</source>
        <translation>Stigende</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="284"/>
        <source>Order:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="315"/>
        <source>Edit Pikeo item</source>
        <translation>Rediger Pikeo post</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="322"/>
        <source>Add Pikeo item</source>
        <translation>Tilføj  Pikeo post</translation>
    </message>
</context>
<context>
    <name>Pikeo::Item</name>
    <message>
        <location filename="../../src/pikeo.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Mærker:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="57"/>
        <source>Order:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="61"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="62"/>
        <source>Most viewed</source>
        <translation>Mest sete</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="63"/>
        <source>Upload date</source>
        <translation>Overført dato</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="64"/>
        <source>Date taken</source>
        <translation>Dato taget</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="65"/>
        <source>Group add date</source>
        <translation>Gruppe tilføj dato</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="66"/>
        <source>Comment date</source>
        <translation>Kommantar dato</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="69"/>
        <source>ascending</source>
        <translation>stigende</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="69"/>
        <source>descending</source>
        <translation>faldende</translation>
    </message>
</context>
<context>
    <name>PositionModel</name>
    <message>
        <location filename="../../src/settings.cpp" line="133"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="136"/>
        <source>Picture smaller than screen on the left, greater than screen on the right</source>
        <translation>Billede mindre end det viste til venstre, større end det viste til højre</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="184"/>
        <source>Hu&amp;e:</source>
        <translation>Nuanc&amp;e:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="185"/>
        <source>&amp;Sat:</source>
        <translation>&amp;Mætning:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="186"/>
        <source>&amp;Val:</source>
        <translation>&amp;Værdi:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="187"/>
        <source>&amp;Red:</source>
        <translation>&amp;Rød:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="188"/>
        <source>&amp;Green:</source>
        <translation>&amp;Grøn:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="189"/>
        <source>Bl&amp;ue:</source>
        <translation>&amp;Blå:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="190"/>
        <source>Select Color</source>
        <translation>Vælg farve</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="191"/>
        <source>&amp;Basic colors</source>
        <translation>&amp;Standard farver</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="192"/>
        <source>&amp;Custom colors</source>
        <translation>&amp;Egne farver</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="193"/>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Tilføj til egne farver</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <location filename="../../src/settings.cpp" line="176"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="177"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="178"/>
        <source>Reset</source>
        <translation>Nulstil</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="179"/>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="180"/>
        <source>&amp;No</source>
        <translation>&amp;Nej</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="181"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="182"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="195"/>
        <source>Directories</source>
        <translation>Mapper</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="196"/>
        <source>&amp;Open</source>
        <translation>&amp;Åben</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="197"/>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="198"/>
        <source>Open</source>
        <translation>Åben</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="199"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 findes allerede.
Ønsker du at overskrive den ?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="200"/>
        <source>%1
File not found.
Please verify the correct file name was given.</source>
        <translation>%1
Fil ikke fundet.
Check angivet filnavn.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="201"/>
        <source>My Computer</source>
        <translation>Min Computer</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="202"/>
        <source>&amp;Rename</source>
        <translation>&amp;Omdøb</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="203"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slet</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="204"/>
        <source>Show &amp;hidden files</source>
        <translation>Vis &amp;skjulte filer</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="205"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="206"/>
        <source>Parent Directory</source>
        <translation>Øvre mappe</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="207"/>
        <source>List View</source>
        <translation>Listevisning</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="208"/>
        <source>Detail View</source>
        <translation>Detailvisning</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="209"/>
        <source>Files of type:</source>
        <translation>Filtyper:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="210"/>
        <source>Directory:</source>
        <translation>Mappe:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="211"/>
        <source>%1
Directory not found.
Please verify the correct directory name was given.</source>
        <translation>%1
Mappen blev ikke fundet.
Check angivet navn.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="212"/>
        <source>&apos;%1&apos; is write protected.
Do you want to delete it anyway?</source>
        <translation>&apos;%1&apos; er skrivebeskyttet.
Ønsker du at slette den alligevel ?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="213"/>
        <source>Are sure you want to delete &apos;%1&apos;?</source>
        <translation>Er du sikker på at du vil slette &apos;%1&apos; ?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="214"/>
        <source>Could not delete directory.</source>
        <translation>Kunne ikke slete mappe.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="215"/>
        <source>Recent Places</source>
        <translation>Tidligeremapper</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="216"/>
        <source>Save As</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="217"/>
        <source>Drive</source>
        <translation>Drev</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="218"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="219"/>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="220"/>
        <source>Find Directory</source>
        <translation>Find mappe</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="221"/>
        <source>Show</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="222"/>
        <source>Forward</source>
        <translation>Frem</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="223"/>
        <source>New Folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="224"/>
        <source>&amp;New Folder</source>
        <translation>&amp;Ny mappe</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="225"/>
        <source>&amp;Choose</source>
        <translation>&amp;Vælg</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="226"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="227"/>
        <source>File &amp;name:</source>
        <translation>Fil &amp;navn:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="228"/>
        <source>Look in:</source>
        <translation>Søg i:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="229"/>
        <source>Create New Folder</source>
        <translation>Opret Ny Mappe</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/settings.cpp" line="31"/>
        <source>Centered</source>
        <translation>Centreret</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="34"/>
        <source>Tiled</source>
        <translation>Overlagt</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="37"/>
        <source>Center Tiled</source>
        <translation>Cntreret overlagt</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="40"/>
        <source>Centered Maxpect</source>
        <translation>Centreret Maxpect</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="43"/>
        <source>Tiled Maxpect</source>
        <translation>Overlagt Maxpect</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="46"/>
        <source>Scaled</source>
        <translation>Skaleret</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="49"/>
        <source>Centered Auto Fit</source>
        <translation>Centreret autotilpasning</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="52"/>
        <source>Scale &amp; Crop</source>
        <translation>Skaler &amp; Beskær</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="55"/>
        <source>Symmetrical Tiled</source>
        <translation>Symereisk Overlagt</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="58"/>
        <source>Mirrored Tiled</source>
        <translation>Spejlet Overlagt</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="61"/>
        <source>Symmetrical Mirrored Tiled</source>
        <translation>Symereisk Spejlet Overlagt</translation>
    </message>
    <message>
        <location filename="../../src/utils.cpp" line="76"/>
        <source>All image files</source>
        <translation>Alle billed filer</translation>
    </message>
    <message>
        <location filename="../../src/utils.cpp" line="80"/>
        <source>files</source>
        <translation>Filer</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <location filename="../../src/history.cpp" line="340"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../ui/settings.ui" line="34"/>
        <source>General options</source>
        <translation>Generelle indstillinger</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="42"/>
        <source>Interval:</source>
        <translation>Interval:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="69"/>
        <source>Border:</source>
        <translation>Ramme:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="86"/>
        <location filename="../../ui/settings.ui" line="221"/>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="144"/>
        <source>Main</source>
        <translation>Hoved</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="153"/>
        <source>Choose in random order</source>
        <translation>Vælg i vilkårlig orden</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="160"/>
        <source>Switch background on play</source>
        <translation>Skift baggrund ved start</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="167"/>
        <source>Play automatically on application start</source>
        <translation>Start automatisk ved programstart</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="174"/>
        <source>Disable splash screen</source>
        <translation>Fravælg splash screen</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="181"/>
        <source>Quit after background change</source>
        <translation>Afslut efter baggrundsændring</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="188"/>
        <source>Start automatically when system starts</source>
        <translation>Start automatisk ved systemstart</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="195"/>
        <source>Only use landscape-oriented photos</source>
        <translation>Brug kun landskabsorienterede billeder</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="202"/>
        <source>Rotate images according to EXIF information</source>
        <translation>Rotér billeder iflg. EXIF information</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="211"/>
        <source>View info on photo</source>
        <translation>Vis info på foto</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="253"/>
        <source>View info in system tray tooltip</source>
        <translation>Vis info i systembakke værktøjstip</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="260"/>
        <source>Use full desktop area</source>
        <translation>Brug hele skrivebords området</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="269"/>
        <source>Photo has to be</source>
        <translation>Foto skalvære</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="280"/>
        <source>independent of</source>
        <translation>uafhængig af</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="285"/>
        <source>at least 1/2 of</source>
        <translation>mindst ½ af</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="290"/>
        <source>at least 3/4 of</source>
        <translation>mindst ¾ af</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="295"/>
        <source>bigger than</source>
        <translation>større end</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="303"/>
        <source>desktop&apos;s size</source>
        <translation>skrivebords størrelse</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="327"/>
        <source>Don&apos;t save locally remote photos if free disk space goes below</source>
        <translation>Gem ikke fjern (net) fotos lokalt hvis diskplads kommer under</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="365"/>
        <source>Store images in history for</source>
        <translation>Gem billed historik i</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="382"/>
        <source>Clear</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="518"/>
        <source>Available modules:</source>
        <translation>Ledige moduler:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="525"/>
        <source>Active modules:</source>
        <translation>Aktive moduler:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="561"/>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="573"/>
        <source>Direct connection</source>
        <translation>Direkte forbindelse</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="583"/>
        <source>Proxy connection</source>
        <translation>Proxy forbindelse</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="607"/>
        <source>Use system proxy</source>
        <translation>Brug system proxy</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="617"/>
        <source>Use custom proxy</source>
        <translation>Brug egen proxy opsætning</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="627"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="637"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="687"/>
        <source>Authentication</source>
        <translation>Autorisation</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="702"/>
        <source>Username:</source>
        <translation>Brugernavn:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="719"/>
        <source>Password:</source>
        <translation>Pasord:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="168"/>
        <location filename="../../src/settings.cpp" line="173"/>
        <location filename="../../src/settings.cpp" line="514"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="239"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="240"/>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="243"/>
        <source>kBytes</source>
        <translation>kBytes</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="244"/>
        <source>MBytes</source>
        <translation>MBytes</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="245"/>
        <source>GBytes</source>
        <translation>GBytes</translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="248"/>
        <source>day(s)</source>
        <translation>
            <numerusform>dag</numerusform>
            <numerusform>dage</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="249"/>
        <source>month(s)</source>
        <translation>
            <numerusform>måned</numerusform>
            <numerusform>måneder</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="299"/>
        <location filename="../../src/settings.cpp" line="524"/>
        <source>second(s)</source>
        <translation>
            <numerusform>sekund</numerusform>
            <numerusform>sekunder</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="300"/>
        <location filename="../../src/settings.cpp" line="525"/>
        <source>minute(s)</source>
        <translation>
            <numerusform>minut</numerusform>
            <numerusform>minutter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="301"/>
        <location filename="../../src/settings.cpp" line="526"/>
        <source>hour(s)</source>
        <translation>
            <numerusform>time</numerusform>
            <numerusform>timer</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="453"/>
        <source>Set position</source>
        <translation>Sæt position</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="514"/>
        <source>Changes won&apos;t be applied. Are you sure?</source>
        <translation>Ændringer vil ikke blive tilføjet. Er du sikker ?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="599"/>
        <source>Clear history</source>
        <translation>Fjern historik</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="599"/>
        <source>Are you sure?</source>
        <translation>Er du sikker ?</translation>
    </message>
</context>
<context>
    <name>SmugMug::DialogWidget</name>
    <message>
        <location filename="../../src/smugmug.cpp" line="252"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/smugmug.cpp" line="275"/>
        <source>Edit SmugMug item</source>
        <translation>Rediger SmugMug post</translation>
    </message>
    <message>
        <location filename="../../src/smugmug.cpp" line="280"/>
        <source>Add SmugMug item</source>
        <translation>Tilføj SmugMug post</translation>
    </message>
</context>
<context>
    <name>SmugMug::Item</name>
    <message>
        <location filename="../../src/smugmug.cpp" line="47"/>
        <source>Text:</source>
        <translation>Tekst:</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    <message>
        <location filename="../../src/main.cpp" line="109"/>
        <source>Loading Files module ...</source>
        <translation>Indlæser Fil moduler ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="116"/>
        <source>Loading Folders module ...</source>
        <translation>Indlæser Mappe moduler ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="123"/>
        <source>Loading Flickr module ...</source>
        <translation>Indlæser Flikr modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="130"/>
        <source>Loading Yahoo! module ...</source>
        <translation>Indlæser Yahoo! modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="137"/>
        <source>Loading Panoramio module ...</source>
        <translation>Indlæser Panoramio modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="151"/>
        <source>Loading Ipernity module ...</source>
        <translation>Indlæser Ipernity modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="158"/>
        <source>Loading Photobucket module ...</source>
        <translation>Indlæser Photobucket modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="165"/>
        <source>Loading Buzznet module ...</source>
        <translation>Indlæser Buzznet modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="172"/>
        <source>Loading Picasa module ...</source>
        <translation>Indlæser Picasa modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="179"/>
        <source>Loading SmugMug module ...</source>
        <translation>Indlæser SmugMug modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="193"/>
        <source>Loading Google module ...</source>
        <translation>Indlæser Google modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="200"/>
        <source>Loading Vladstudio module ...</source>
        <translation>Indlæser Vladstudio modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="207"/>
        <source>Loading deviantART module ...</source>
        <translation>Indlæser divantART modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="214"/>
        <source>Loading settings ...</source>
        <translation>Indlæser indstillinger ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="221"/>
        <source>Launching Wally ...</source>
        <translation>Starter Wally ...</translation>
    </message>
    <message>
        <location filename="../../src/splash.cpp" line="46"/>
        <source>Author:</source>
        <translation>Forfatter:</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="../../ui/viewer.ui" line="9"/>
        <source>Right-click on photo to show actions</source>
        <translation>Højreklik på foto for at vise muligheder</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="63"/>
        <source>Fit to window</source>
        <translation>Tilpas til vindue</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="72"/>
        <source>Show full image</source>
        <translation>Vis fuldt billede</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="81"/>
        <source>Zoom in</source>
        <translation>Zoom ind</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="90"/>
        <source>Zoom out</source>
        <translation>Zoom ud</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="99"/>
        <source>Rotate clockwise</source>
        <translation>Rotér med uret</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="108"/>
        <source>Rotate c. clockwise</source>
        <translation>Rotér mod uret</translation>
    </message>
</context>
<context>
    <name>Vladstudio::DialogWidget</name>
    <message>
        <location filename="../../src/vladstudio.cpp" line="325"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="326"/>
        <source>Abstract art</source>
        <translation>Abstrakt kunst</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="327"/>
        <source>Creatures</source>
        <translation>Skabninger</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="328"/>
        <source>Illustrations</source>
        <translation>Illustrationer</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="329"/>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="334"/>
        <source>By ID</source>
        <translation>Efter ID</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="335"/>
        <source>By view count</source>
        <translation>Efter antal visninger</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="340"/>
        <source>Ascending</source>
        <translation>Stigende</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="341"/>
        <source>Descending</source>
        <translation>Faldende</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="344"/>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="345"/>
        <source>Order:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="346"/>
        <source>Direction:</source>
        <translation>Retning:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="368"/>
        <source>Edit Vladstudio item</source>
        <translation>Rediger Vladstudio post</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="375"/>
        <source>Add Vladstudio item</source>
        <translation>Tilføj Vladstudio post</translation>
    </message>
</context>
<context>
    <name>Vladstudio::Item</name>
    <message>
        <location filename="../../src/vladstudio.cpp" line="42"/>
        <source>All categories</source>
        <translation>Alle kategorier</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="46"/>
        <source>Abstract art</source>
        <translation>Abstrakt kunst</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="50"/>
        <source>Creatures</source>
        <translation>Skabninger</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="54"/>
        <source>Illustrations</source>
        <translation>Illustrationer</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="58"/>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="89"/>
        <source>by Id</source>
        <translation>Efter ID</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="93"/>
        <source>by view count</source>
        <translation>Efter antal visninger</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="105"/>
        <source>ascending</source>
        <translation>stigende</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="109"/>
        <source>descending</source>
        <translation>faldende</translation>
    </message>
</context>
<context>
    <name>Wally::Application</name>
    <message>
        <location filename="../../src/wally.cpp" line="611"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="613"/>
        <location filename="../../src/wally.cpp" line="2008"/>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="615"/>
        <location filename="../../src/wally.cpp" line="1988"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="616"/>
        <source>Next photo</source>
        <translation>Næste foto</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="617"/>
        <source>Save photo...</source>
        <translation>Gem foto...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="618"/>
        <source>Get EXIF info...</source>
        <translation>Hent EXIF info...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="619"/>
        <source>Settings...</source>
        <translation>Indstillinger...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="620"/>
        <source>Explore source</source>
        <translation>Undersøg kilde</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="621"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="622"/>
        <source>History...</source>
        <translation>Historie...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="623"/>
        <source>About Qt...</source>
        <translation>Om Qt...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="624"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="625"/>
        <source>Languages</source>
        <translation>Sprog</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="627"/>
        <source>English</source>
        <translation>Engelsk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="628"/>
        <source>Italian</source>
        <translation>Italiensk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="629"/>
        <source>Spanish</source>
        <translation>Spansk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="630"/>
        <source>German</source>
        <translation>Tysk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="631"/>
        <source>French</source>
        <translation>Fransk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="632"/>
        <source>Russian</source>
        <translation>Russisk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="633"/>
        <source>Portuguese (Brazil)</source>
        <translation>Portugisisk (Braziliansk)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="634"/>
        <source>Czech</source>
        <translation>Tjekkisk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="635"/>
        <source>Polish</source>
        <translation>Polsk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="636"/>
        <source>Chinese</source>
        <translation>Kinesisk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="637"/>
        <source>Catalan</source>
        <translation>Katalansk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="638"/>
        <source>Greek</source>
        <translation>Græsk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="639"/>
        <source>Korean</source>
        <translation>Koreansk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="640"/>
        <source>Hungarian</source>
        <translation>Ungarsk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="641"/>
        <source>Danish</source>
        <translation>Dansk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="642"/>
        <source>Swedish</source>
        <translation>Svensk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="643"/>
        <source>Turkish</source>
        <translation>Tyrkisk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1579"/>
        <source>Wally Error</source>
        <translation>Wally fejl</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1579"/>
        <source>Active Desktop must be disabled</source>
        <translation>Det aktive skrivebord skal deaktiveres</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1668"/>
        <location filename="../../src/wally.cpp" line="1959"/>
        <source>by:</source>
        <translation>af:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1677"/>
        <source>Location:</source>
        <translation>Lokation:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1685"/>
        <location filename="../../src/wally.cpp" line="1964"/>
        <source>Engine:</source>
        <translation>Motor:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2048"/>
        <location filename="../../src/wally.cpp" line="2051"/>
        <source>Save photo</source>
        <translation>Gem foto</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2049"/>
        <location filename="../../src/wally.cpp" line="2053"/>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Billedtyper (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2548"/>
        <source>Right-click to show main menu</source>
        <translation>Højreklik for at vise hovedmenu</translation>
    </message>
</context>
<context>
    <name>Yahoo::DialogWidget</name>
    <message>
        <location filename="../../src/yahoo.cpp" line="268"/>
        <source>All of these words</source>
        <translation>Alle disse ord</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="269"/>
        <source>Any of these words</source>
        <translation>Et af disse ord</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="272"/>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="277"/>
        <source>Filter content</source>
        <translation>Filtrer indhold</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="297"/>
        <source>Yahoo! item</source>
        <translation>Yahoo! post</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="298"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ufiltreret indhold kan vise upassende eller direkte pornografiske billeder</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="309"/>
        <source>Edit Yahoo! item</source>
        <translation>Rediger Yahoo! post</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="317"/>
        <source>Add Yahoo! item</source>
        <translation>Tilføj Yahoo! post</translation>
    </message>
</context>
<context>
    <name>Yahoo::Item</name>
    <message>
        <location filename="../../src/yahoo.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Mærke:</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="58"/>
        <source>and</source>
        <translation>og</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="58"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="61"/>
        <source>content filtered</source>
        <translation>filtreret indhold</translation>
    </message>
</context>
</TS>
